# Contributing to BNLP

Hi, thanks for your interest. We know, we always suffer from scarcity of good tools/resources for processing Bengali language. 
[BNLP](https://github.com/sagorbrur/bnlp) is a great initiative to solve this problem.
Your contribution can make this initiative more powerful and also help millions of Bengali developer to process Bengali language
more efficiently. 

## Current Features
* Bengali Tokenization
* Bengali Word Embedding
* Bengali POS Tagging
* Bengali NER

**To make this tool more effective you can add below features as well as other features too**

* **Bengali Lemmatization**
* **Bengali Spell Checker**
* so on.................. 



In this document, we summarize everything, so that you can contribute easily and make this tool more powerful.

# Code and Issues

We hosted our code repositories in Github for better management of issues and development.

* [bnlp](https://github.com/sagorbrur/bnlp) is the main repository with code related library

# Detail Approaches

## Environment Setup

- Fork the [bnlp](https://github.com/sagorbrur/bnlp) repository on GitHub
  to your account;
- Clone your forked repository locally
  (`git clone https://github.com/<your-github-username>/bnlp.git`);
- Run `cd bnlp` to get to the root directory of the `bnlp` code base;
- Install the dependencies (`pip install -r requirements.txt`);
- Download the pretrianed models for running tests
  (you can find the pretrained model details [here](https://github.com/sagorbrur/bnlp) in Readme

## Approaches

* To add new feature inside [bnlp/bnlp](https://github.com/sagorbrur/bnlp/tree/master/bnlp) create your objective script with proper testing.
* To modify any script please do modification with proper testing and send pull request.

## Discussion/Reporting
* Use [issue](https://github.com/sagorbrur/bnlp/issues) tab for issue, bug reporting or discussion.

Thanks and Happy coding!
